@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 # set up version info
-our $VERSION= '0.11';
+our $VERSION= '0.12';
 
 # we need this otherwise nothing works
 use Data::Alias qw( alias copy );
@@ -62,8 +62,7 @@ sub reuse (@); # needed because of recursion
 sub reuse (@) {
 
     # being called with return values
-    my $not_void= defined wantarray;
-
+    alias my $not_void = defined wantarray;
     # we're one level deeper
     $level++;
 
@@ -168,9 +167,8 @@ sub reuse (@) {
 
                                 # not seen, recurse, set result if first
                                 if ( !$reuse{$id} ) {
-                                    ($scalar)= reuse $scalar;
+		                   ($scalar) = reuse $scalar;
                                     copy Internals::SvREADONLY $scalar, 1;
-
                                     # recursive structures may be replaced
                                     $id= md5( $S . $scalar );
                                 }
@@ -195,11 +193,10 @@ sub reuse (@) {
      are also not going to overwrite anything that's there already.
 
 =cut
-
                         $reuse{$id} ||= $_ if $not_void;
 
                         # store in data store
-                        $reuse{$_}= $reuse{$id} || $_;
+                        $reuse{$_} = $reuse{$id} || $_;
                     };   #alias
 
                     # done handling this ref
@@ -415,7 +412,7 @@ Data::Reuse - share constant values with Data::Alias
 
 =head1 VERSION
 
-This documentation describes version 0.11.
+This documentation describes version 0.12.
 
 =head1 SYNOPSIS
 
